==> haskell-wai-logger-2.5.0-123-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-logger
version:              2.5.0
visibility:           public
id:                   wai-logger-2.5.0-JyqLkRnrpReOLoa4DPsbr
key:                  wai-logger-2.5.0-JyqLkRnrpReOLoa4DPsbr
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             A logging system for WAI
description:          A logging system for WAI(Web Application Interface)
category:             Web, Yesod
abi:                  2158a0e87d880cc9bb4915a5aaa0d8bf
exposed:              True
exposed-modules:      Network.Wai.Logger
hidden-modules:
    Network.Wai.Logger.Apache Network.Wai.Logger.IP
    Network.Wai.Logger.IORef

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-logger-2.5.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-logger-2.5.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-logger-2.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-logger
hs-libraries:         HSwai-logger-2.5.0-JyqLkRnrpReOLoa4DPsbr
depends:
    base-4.17.2.1 byteorder-1.0.4-GnZZPnCtMLjHLa4McP5dl3
    bytestring-0.11.5.3 fast-logger-3.2.4-BpzBlTxgS5DB3J0en1gevm
    http-types-0.12.4-AnyveerSvWp9fcmJ7pBmmy
    network-3.1.4.0-4cEUA9pnnvEEvGlZk2FqT
    wai-3.2.4-6yvNKQ0UUswJzjrPe1tuVO

haddock-interfaces:   /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
haddock-html:         /usr/share/doc/haskell-wai-logger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-logger-2.5.0-124-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-logger
version:              2.5.0
visibility:           public
id:                   wai-logger-2.5.0-L9iqIrAc33B4FOWjpkJ5kB
key:                  wai-logger-2.5.0-L9iqIrAc33B4FOWjpkJ5kB
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             A logging system for WAI
description:          A logging system for WAI(Web Application Interface)
category:             Web, Yesod
abi:                  551ef955e6ca00c3f40a1963452577f3
exposed:              True
exposed-modules:      Network.Wai.Logger
hidden-modules:
    Network.Wai.Logger.Apache Network.Wai.Logger.IP
    Network.Wai.Logger.IORef

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-logger-2.5.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-logger-2.5.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-logger-2.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-logger
hs-libraries:         HSwai-logger-2.5.0-L9iqIrAc33B4FOWjpkJ5kB
depends:
    base-4.17.2.1 byteorder-1.0.4-GnZZPnCtMLjHLa4McP5dl3
    bytestring-0.11.5.3 fast-logger-3.2.4-7XwUX0NOhm7HKGD1lYGUb4
    http-types-0.12.4-8HR0lcMpUwL4edtlDqx8uG
    network-3.1.4.0-4UbSgXPdAp7DQ7Pftr1aPB
    wai-3.2.4-54grchYoKyyD66je19YTSn

haddock-interfaces:   /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
haddock-html:         /usr/share/doc/haskell-wai-logger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
